@@ -1,3 +1,3 @@
 from .iotawatt import Iotawatt  # noqa: F401
 from .connection import Connection  # noqa: F401
-from .sensorio import SensorIO  # noqa: F401
+from .sensor import Sensor  # noqa: F401
